@@ -1,10 +1,10 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: address.py 917 2009-01-02 19:34:06Z mac $
+# $Id: address.py 997 2009-02-03 16:58:46Z mac $
 
 import persistent
-import zope.app.container.contained
+import zope.container.contained
 import zope.interface
 import zope.schema.fieldproperty
 
@@ -14,7 +14,7 @@ from icemac.addressbook.i18n import MessageFactory as _
 
 
 class PostalAddress(
-    persistent.Persistent, zope.app.container.contained.Contained):
+    persistent.Persistent, zope.container.contained.Contained):
     "A postal address."
 
     zope.interface.implements(icemac.addressbook.interfaces.IPostalAddress)
@@ -66,7 +66,7 @@ def postal_address_title(address):
     return title
 
 class EMailAddress(
-    persistent.Persistent, zope.app.container.contained.Contained):
+    persistent.Persistent, zope.container.contained.Contained):
     """An e-mail address."""
 
     zope.interface.implements(icemac.addressbook.interfaces.IEMailAddress)
@@ -90,7 +90,7 @@ def email_address_title(email):
 
 
 class HomePageAddress(
-    persistent.Persistent, zope.app.container.contained.Contained):
+    persistent.Persistent, zope.container.contained.Contained):
     """A home page address."""
 
     zope.interface.implements(icemac.addressbook.interfaces.IHomePageAddress)
@@ -114,7 +114,7 @@ def home_page_address_title(hp):
 
 
 class PhoneNumber(
-    persistent.Persistent, zope.app.container.contained.Contained):
+    persistent.Persistent, zope.container.contained.Contained):
     """A phone number."""
 
     zope.interface.implements(icemac.addressbook.interfaces.IPhoneNumber)
