@@ -1,15 +1,15 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: keyword.py 913 2009-01-02 12:47:38Z mac $
+# $Id: keyword.py 1037 2009-03-05 17:52:10Z mac $
 
+from icemac.addressbook.i18n import MessageFactory as _
 import gocept.reference.interfaces
+import icemac.addressbook.browser.base
+import icemac.addressbook.interfaces
 import z3c.form.button
 import zope.component
-
-import icemac.addressbook.interfaces
-import icemac.addressbook.browser.base
-from icemac.addressbook.i18n import MessageFactory as _
+import zope.traversing.browser.interfaces
 
 
 class AddForm(icemac.addressbook.browser.base.BaseAddForm):
@@ -49,7 +49,8 @@ class EditForm(icemac.addressbook.browser.base.BaseEditForm):
         _(u'Delete'), name='delete', condition=can_delete_keyword)
     def handleDelete(self, action):
         url = zope.component.getMultiAdapter(
-            (self.context, self.request), name="absolute_url")()
+            (self.context, self.request),
+            zope.traversing.browser.interfaces.IAbsoluteURL)()
         self.request.response.redirect(url + '/@@delete.html')
 
 
