@@ -1,23 +1,22 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: person.py 917 2009-01-02 19:34:06Z mac $
-
-import z3c.form.button
-import z3c.form.datamanager
-import z3c.form.group
-import zc.sourcefactory.contextual
-import zope.component
+# $Id: person.py 1081 2009-03-28 20:03:50Z mac $
 
+from icemac.addressbook.address import interface_title_prefix_class_mapping
+from icemac.addressbook.i18n import MessageFactory as _
+import gocept.reference.interfaces
 import icemac.addressbook.browser.base
 import icemac.addressbook.interfaces
 import icemac.addressbook.person
 import icemac.addressbook.sources
 import icemac.addressbook.utils
-
-from icemac.addressbook.i18n import MessageFactory as _
-from icemac.addressbook.address import interface_title_prefix_class_mapping
-
+import z3c.form.button
+import z3c.form.datamanager
+import z3c.form.group
+import zc.sourcefactory.contextual
+import zope.component
+import zope.traversing.browser.interfaces
 
 def prefix_to_class(prefix):
     mapping = dict((x[2], x[3]) for x in interface_title_prefix_class_mapping)
@@ -87,6 +86,13 @@ class PersonAddForm(z3c.form.group.GroupForm,
         return person
 
 
+def person_deletable(form):
+    "Button display constraint which checks whether a person is deleteable."
+    person = form.context
+    ref_target = gocept.reference.interfaces.IReferenceTarget(person)
+    return not ref_target.is_referenced(recursive=False)
+
+
 class PersonEditForm(
     z3c.form.group.GroupForm, icemac.addressbook.browser.base.BaseEditForm):
 
@@ -125,11 +131,13 @@ class PersonEditForm(
 
     @z3c.form.button.buttonAndHandler(
         _(u'Delete person'), name='delete_person',
-        condition=icemac.addressbook.browser.base.can_access(
-            '@@delete_person.html'))
+        condition=icemac.addressbook.browser.base.all_(
+            icemac.addressbook.browser.base.can_access('@@delete_person.html'),
+            person_deletable))
     def handleDeletePerson(self, action):
         url = zope.component.getMultiAdapter(
-            (self.context, self.request), name="absolute_url")()
+            (self.context, self.request),
+            zope.traversing.browser.interfaces.IAbsoluteURL)()
         self.request.response.redirect(url + '/@@delete_person.html')
 
     @z3c.form.button.buttonAndHandler(
@@ -138,7 +146,8 @@ class PersonEditForm(
             '@@delete_address.html'))
     def handleDeleteAddress(self, action):
         url = zope.component.getMultiAdapter(
-            (self.context, self.request), name="absolute_url")()
+            (self.context, self.request),
+            zope.traversing.browser.interfaces.IAbsoluteURL)()
         self.request.response.redirect(url + '/@@delete_address.html')
 
 
@@ -159,6 +168,13 @@ class DeletePersonForm(icemac.addressbook.browser.base.BaseDeleteForm):
     interface = icemac.addressbook.interfaces.IPerson
     field_names = ('first_name', 'last_name')
 
+    def _do_delete(self):
+        try:
+            super(DeletePersonForm, self)._do_delete()
+        except gocept.reference.interfaces.IntegrityError:
+            pass # XXX abort transaction (IntegrityError dooms it) and
+                 # set notice using z3c.flashmessage
+
 
 class PersonEntriesSource(
     zc.sourcefactory.contextual.BasicContextualSourceFactory):
@@ -201,7 +217,8 @@ class DeleteAddressForm(icemac.addressbook.browser.base.BaseEditForm):
         selected_entry = data['entry']
 
         url = zope.component.getMultiAdapter(
-            (selected_entry, self.request), name="absolute_url")()
+            (selected_entry, self.request),
+            zope.traversing.browser.interfaces.IAbsoluteURL)()
         self.request.response.redirect(url + '/@@delete.html')
 
     @z3c.form.button.buttonAndHandler(_(u'Cancel'), name='cancel')
