@@ -1,9 +1,9 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: simple_single_keyword.py 913 2009-01-02 12:47:38Z mac $
+# $Id: simple_single_keyword.py 1001 2009-02-07 08:10:56Z mac $
 
-import zope.app.catalog.interfaces
+import zope.catalog.interfaces
 import zope.component
 import zope.interface
 import zope.schema
@@ -17,7 +17,7 @@ from icemac.addressbook.i18n import MessageFactory as _
 
 class SearchView(icemac.addressbook.browser.search.base.BaseView):
     pass
-    
+
 
 class Search(object):
     """Search for a single keyword."""
@@ -30,8 +30,7 @@ class Search(object):
 
     def search(self, keyword):
         keyword = keyword.title
-        catalog = zope.component.getUtility(
-            zope.app.catalog.interfaces.ICatalog)
+        catalog = zope.component.getUtility(zope.catalog.interfaces.ICatalog)
         result_set = catalog.searchResults(keywords={'any_of': (keyword, )})
         return result_set
 
@@ -39,10 +38,10 @@ class Search(object):
 class ISingleSimpleKeyword(zope.interface.Interface):
 
     keyword = zope.schema.Choice(
-        title=_('keyword'), 
+        title=_('keyword'),
         source=icemac.addressbook.sources.keyword_source)
 
 
 class SearchForm(icemac.addressbook.browser.search.base.BaseSearchForm):
-    
+
     interface = ISingleSimpleKeyword
