@@ -1,22 +1,16 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: simple.py 917 2009-01-02 19:34:06Z mac $
+# $Id: simple.py 1093 2009-03-31 19:17:47Z mac $
 
+from cStringIO import StringIO
+from icemac.addressbook.address import interface_title_prefix_class_mapping
+from icemac.addressbook.i18n import MessageFactory as _
 import datetime
-import xlwt
-import zope.interface
-
-try:
-    from cStringIO import StringIO
-except ImportError:
-    from StringIO import StringIO
-
 import icemac.addressbook.export.interfaces
 import icemac.addressbook.interfaces
-
-from icemac.addressbook.i18n import MessageFactory as _
-from icemac.addressbook.address import interface_title_prefix_class_mapping
+import xlwt
+import zope.interface
 
 
 # fonts
