@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 918 2009-01-02 19:35:06Z mac $
+# $Id: tests.py 935 2009-01-08 10:19:09Z mac $
 
 import gocept.reference.verify
 import unittest
@@ -16,21 +16,7 @@ import icemac.addressbook.addressbook
 import icemac.addressbook.interfaces
 import icemac.addressbook.keyword
 import icemac.addressbook.person
-
-
-class AddressBookUnitTests(zope.testing.testrunner.layer.UnitTests):
-    """Layer for gathering addressbook unit tests."""
-
-    @classmethod
-    def setUp(cls):
-        # some classes use gocept.reference and store default values for
-        # which annotations are needed.
-        zope.component.provideAdapter(
-            zope.annotation.attribute.AttributeAnnotations)
-
-    @classmethod
-    def tearDown(cls):
-        zope.testing.cleanup.tearDown()
+import icemac.addressbook.testing
 
 
 class TestInterfaces(unittest.TestCase):
@@ -85,5 +71,5 @@ class TestInterfaces(unittest.TestCase):
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(TestInterfaces))
-    suite.layer = AddressBookUnitTests
+    suite.layer = icemac.addressbook.testing.AddressBookUnitTests
     return suite
