@@ -13,14 +13,14 @@
 ##############################################################################
 """Submit Widget Implementation
 
-$Id: image.py 93230 2008-11-21 09:14:51Z adamg $
+$Id: image.py 96365 2009-02-10 03:48:08Z nadako $
 """
 __docformat__ = "reStructuredText"
 import zope.component
 import zope.interface
 import zope.traversing.api
 from zope.schema.fieldproperty import FieldProperty
-from zope.app.component import hooks
+from zope.site import hooks
 
 from z3c.form import interfaces
 from z3c.form.widget import FieldWidget
@@ -34,7 +34,7 @@ class ImageWidget(button.ButtonWidget):
     src = FieldProperty(IHTMLImageWidget['src'])
     klass = u'image-widget'
 
-    def extract(self, default=interfaces.NOVALUE, setErrors=True):
+    def extract(self, default=interfaces.NO_VALUE):
         """See z3c.form.interfaces.IWidget."""
         if self.name + '.x' not in self.request:
             return default
