@@ -5,7 +5,7 @@
 ###############################################################################
 
 """
-$Id: tests.py 93492 2008-12-01 16:50:04Z adamg $
+$Id: tests.py 96460 2009-02-12 07:29:55Z wosc $
 """
 __docformat__ = "reStructuredText"
 
@@ -18,7 +18,7 @@ from zope.testing.doctestunit import DocFileSuite
 from z3c.form import testing
 
 def test_suite():
-    checker = testing.OutputChecker()
+    checker = testing.OutputChecker(doctest)
 
     tests = ((
         DocFileSuite('README.txt',
@@ -71,6 +71,11 @@ def test_suite():
                      optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
                      checker=checker,
                      ),
+        DocFileSuite('select-source.txt',
+                     setUp=setUp, tearDown=testing.tearDown,
+                     optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
+                     checker=checker,
+                     ),
         DocFileSuite('submit.txt',
                      setUp=setUp, tearDown=testing.tearDown,
                      optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
