@@ -13,7 +13,7 @@
 ##############################################################################
 """Field Implementation
 
-$Id: field.py 93230 2008-11-21 09:14:51Z adamg $
+$Id: field.py 97967 2009-03-12 08:36:26Z sagblmi $
 """
 __docformat__ = "reStructuredText"
 import zope.component
@@ -101,7 +101,7 @@ class Fields(util.SelectionManager):
             elif zope.schema.interfaces.IField.providedBy(arg):
                 name = arg.__name__
                 if not name:
-                        raise ValueError("Field has no name")
+                    raise ValueError("Field has no name")
                 fields.append((name, arg, arg.interface))
 
             elif self.managerInterface.providedBy(arg):
@@ -179,9 +179,11 @@ class FieldWidgets(util.Manager):
     prefix = 'widgets.'
     mode = interfaces.INPUT_MODE
     errors = ()
+    hasRequiredFields = False
     ignoreContext = False
     ignoreRequest = False
     ignoreReadonly = False
+    setErrors = True
 
     def __init__(self, form, request, content):
         super(FieldWidgets, self).__init__()
@@ -222,6 +224,7 @@ class FieldWidgets(util.Manager):
         prefix = util.expandPrefix(self.form.prefix)
         prefix += util.expandPrefix(self.prefix)
         # Walk through each field, making a widget out of it.
+        uniqueOrderedKeys = []
         for field in self.form.fields.values():
             # Step 0. Determine whether the context should be ignored.
             ignoreContext = self.ignoreContext
@@ -232,7 +235,7 @@ class FieldWidgets(util.Manager):
             if field.mode is not None:
                 mode = field.mode
             elif field.field.readonly and not self.ignoreReadonly:
-                    mode = interfaces.DISPLAY_MODE
+                mode = interfaces.DISPLAY_MODE
             elif not ignoreContext:
                 # If we do not have enough permissions to write to the
                 # attribute, then switch to display mode.
@@ -241,14 +244,19 @@ class FieldWidgets(util.Manager):
                 if not dm.canWrite():
                     mode = interfaces.DISPLAY_MODE
             # Step 2: Get the widget for the given field.
-            factory = field.widgetFactory.get(mode)
-            if factory is not None:
+            shortName = field.__name__
+            newWidget = True
+            if shortName in self._data:
+                # reuse existing widget
+                widget = self._data[shortName]
+                newWidget = False
+            elif field.widgetFactory.get(mode) is not None:
+                factory = field.widgetFactory.get(mode)
                 widget = factory(field.field, self.request)
             else:
                 widget = zope.component.getMultiAdapter(
                     (field.field, self.request), interfaces.IFieldWidget)
             # Step 3: Set the prefix for the widget
-            shortName = field.__name__
             widget.name = prefix + shortName
             widget.id = (prefix + shortName).replace('.', '-')
             # Step 4: Set the context
@@ -268,12 +276,18 @@ class FieldWidgets(util.Manager):
             widget.update()
             zope.event.notify(AfterWidgetUpdateEvent(widget))
             # Step 9: Add the widget to the manager
-            self._data_keys.append(shortName)
-            self._data_values.append(widget)
-            self._data[shortName] = widget
-            zope.location.locate(widget, self, shortName)
+            if widget.required:
+                self.hasRequiredFields = True
+            uniqueOrderedKeys.append(shortName)
+            if newWidget:
+                self._data_values.append(widget)
+                self._data[shortName] = widget
+                zope.location.locate(widget, self, shortName)
+            # allways ensure that we add all keys and keep the order given from
+            # button items
+            self._data_keys = uniqueOrderedKeys
 
-    def extract(self, setErrors=True):
+    def extract(self):
         """See interfaces.IWidgets"""
         data = {}
         errors = ()
@@ -282,8 +296,9 @@ class FieldWidgets(util.Manager):
                 continue
             value = widget.field.missing_value
             try:
-                raw = widget.extract(setErrors=setErrors)
-                if raw is not interfaces.NOVALUE:
+                widget.setErrors = self.setErrors
+                raw = widget.extract()
+                if raw is not interfaces.NO_VALUE:
                     value = interfaces.IDataConverter(widget).toFieldValue(raw)
                 zope.component.getMultiAdapter(
                     (self.content,
@@ -298,7 +313,7 @@ class FieldWidgets(util.Manager):
                     (error, self.request, widget, widget.field,
                      self.form, self.content), interfaces.IErrorViewSnippet)
                 view.update()
-                if setErrors:
+                if self.setErrors:
                     widget.error = view
                 errors += (view,)
             else:
@@ -310,6 +325,6 @@ class FieldWidgets(util.Manager):
                 interfaces.IErrorViewSnippet)
             view.update()
             errors += (view,)
-        if setErrors:
+        if self.setErrors:
             self.errors = errors
         return data, errors
